searchData={"items":[{"type":"module","title":"Pluscode","doc":"Convert locations to and from Open Location Codes (Plus Codes).\n\nPlus Codes are short, 10-11 character codes that can be used instead\nof street addresses. The codes can be generated and decoded offline, and use\na reduced character set that minimizes the chance of codes including words.\n\nCodes are able to be shortened relative to a nearby location. This means that\nin many cases, only four to seven characters of the code are needed.\nTo recover the original code, the same location is not required, as long as\na nearby location is provided.\n\nCodes represent rectangular areas rather than points, and the longer the\ncode, the smaller the area. A 10 character code represents a 13.5x13.5\nmeter area (at the equator). An 11 character code represents approximately\na 2.8x3.5 meter area.","ref":"Pluscode.html"},{"type":"function","title":"Pluscode.__struct__/0","doc":"A struct representing the coordinates of a decoded Open Location Code.\n\nThe coordinates include the latitude and longitude of the lower left and\nupper right corners and the center of the bounding box for the area the\ncode represents.","ref":"Pluscode.html#__struct__/0"},{"type":"function","title":"Fields - Pluscode.__struct__/0","doc":"* `:latitude_lo` - The latitude of the SW corner in degrees.\n* `:longitude_lo` - The longitude of the SW corner in degrees.\n* `:latitude_hi` - The latitude of the NE corner in degrees.\n* `:longitude_hi` - The longitude of the NE corner in degrees.\n* `:latitude_center` - The latitude of the center in degrees.\n* `:longitude_center` - The longitude of the center in degrees.\n* `:code_length` - The number of significant characters that were in the code (excluding separator).","ref":"Pluscode.html#__struct__/0-fields"},{"type":"function","title":"Pluscode.compute_latitude_precision/1","doc":"Compute the latitude precision value for a given code length.","ref":"Pluscode.html#compute_latitude_precision/1"},{"type":"function","title":"Args - Pluscode.compute_latitude_precision/1","doc":"* `code_length` - The length of the code to compute precision for.","ref":"Pluscode.html#compute_latitude_precision/1-args"},{"type":"function","title":"Returns - Pluscode.compute_latitude_precision/1","doc":"The precision value in degrees. For lengths <= 10, latitude and longitude\n  have the same precision. For lengths > 10, latitude has a different precision\n  due to the grid method having fewer columns than rows.","ref":"Pluscode.html#compute_latitude_precision/1-returns"},{"type":"function","title":"Examples - Pluscode.compute_latitude_precision/1","doc":"iex> Pluscode.compute_latitude_precision(10)\n    0.000125\n\n    iex> Pluscode.compute_latitude_precision(11)\n    2.5e-5","ref":"Pluscode.html#compute_latitude_precision/1-examples"},{"type":"function","title":"Pluscode.decode/1","doc":"Decodes an Open Location Code into the location coordinates.\nReturns a Pluscode struct that includes the coordinates of the bounding\nbox - the lower left, center and upper right.\nArgs:\n  code: The Open Location Code to decode.\nReturns:\n  A Pluscode struct that provides the latitude and longitude of two of the\n  corners of the area, the center, and the length of the original code.","ref":"Pluscode.html#decode/1"},{"type":"function","title":"Pluscode.encode/3","doc":"Encode a location into an Open Location Code.","ref":"Pluscode.html#encode/3"},{"type":"function","title":"Args - Pluscode.encode/3","doc":"* `latitude` - The latitude in signed decimal degrees. Must be between -90 and 90.\n  * `longitude` - The longitude in signed decimal degrees. Must be between -180 and 180.\n  * `code_length` - The number of significant digits in the output code (default: 10).\n                   The length determines the precision of the code.","ref":"Pluscode.html#encode/3-args"},{"type":"function","title":"Returns - Pluscode.encode/3","doc":"A string containing the Open Location Code.","ref":"Pluscode.html#encode/3-returns"},{"type":"function","title":"Examples - Pluscode.encode/3","doc":"iex> Pluscode.encode(47.365590, 8.524997)\n    \"8FVC9G8F+6X\"\n\n    iex> Pluscode.encode(47.365590, 8.524997, 11)\n    \"8FVC9G8F+6XQ\"","ref":"Pluscode.html#encode/3-examples"},{"type":"function","title":"Pluscode.full?/1","doc":"Determines if a code is a valid full Open Location Code.\n\nNot all possible combinations of Open Location Code characters decode to\nvalid latitude and longitude values. This checks that a code is valid\nand also that the latitude and longitude values are legal.","ref":"Pluscode.html#full?/1"},{"type":"function","title":"Args - Pluscode.full?/1","doc":"* `code` - The code to check.","ref":"Pluscode.html#full?/1-args"},{"type":"function","title":"Returns - Pluscode.full?/1","doc":"`true` if the code is a valid full code, `false` otherwise.","ref":"Pluscode.html#full?/1-returns"},{"type":"function","title":"Rules - Pluscode.full?/1","doc":"* If the prefix character is present, it must be the first character.\n  * If the separator character is present, it must be after four characters.\n  * The first latitude character must decode to a valid latitude (<90 degrees).\n  * The first longitude character must decode to a valid longitude (<180 degrees).","ref":"Pluscode.html#full?/1-rules"},{"type":"function","title":"Examples - Pluscode.full?/1","doc":"iex> Pluscode.full?(\"8FVC9G8F+6X\")\n    true\n\n    iex> Pluscode.full?(\"9G8F+6X\")\n    false","ref":"Pluscode.html#full?/1-examples"},{"type":"function","title":"Pluscode.normalize_longitude/1","doc":"Normalize a longitude into the range -180 to 180, not including 180.","ref":"Pluscode.html#normalize_longitude/1"},{"type":"function","title":"Args - Pluscode.normalize_longitude/1","doc":"* `longitude` - A longitude in signed decimal degrees.","ref":"Pluscode.html#normalize_longitude/1-args"},{"type":"function","title":"Returns - Pluscode.normalize_longitude/1","doc":"The normalized longitude value.","ref":"Pluscode.html#normalize_longitude/1-returns"},{"type":"function","title":"Examples - Pluscode.normalize_longitude/1","doc":"iex> Pluscode.normalize_longitude(185)\n    -175\n\n    iex> Pluscode.normalize_longitude(-185)\n    175","ref":"Pluscode.html#normalize_longitude/1-examples"},{"type":"function","title":"Pluscode.recover_nearest/3","doc":"Recover the nearest matching code to a specified location.\nRecover the nearest matching full code to a specified location.\n\nGiven a short code of between four and seven characters, this recovers\nthe nearest matching full code to the specified location.","ref":"Pluscode.html#recover_nearest/3"},{"type":"function","title":"Args - Pluscode.recover_nearest/3","doc":"* `code` - A valid short Open Location Code.\n  * `reference_latitude` - The reference latitude in signed decimal degrees.\n  * `reference_longitude` - The reference longitude in signed decimal degrees.","ref":"Pluscode.html#recover_nearest/3-args"},{"type":"function","title":"Returns - Pluscode.recover_nearest/3","doc":"A string containing the nearest matching full Open Location Code.","ref":"Pluscode.html#recover_nearest/3-returns"},{"type":"function","title":"Examples - Pluscode.recover_nearest/3","doc":"iex> Pluscode.recover_nearest(\"9G8F+6X\", 47.4, 8.6)\n    \"8FVC9G8F+6X\"","ref":"Pluscode.html#recover_nearest/3-examples"},{"type":"function","title":"Pluscode.short?/1","doc":"Determines if a code is a valid short code.\n\nA short Open Location Code is a sequence created by removing four or more\ndigits from an Open Location Code. It must include a separator character.","ref":"Pluscode.html#short?/1"},{"type":"function","title":"Args - Pluscode.short?/1","doc":"* `code` - The code to check.","ref":"Pluscode.html#short?/1-args"},{"type":"function","title":"Returns - Pluscode.short?/1","doc":"`true` if the code is a valid short code, `false` otherwise.","ref":"Pluscode.html#short?/1-returns"},{"type":"function","title":"Examples - Pluscode.short?/1","doc":"iex> Pluscode.short?(\"9G8F+6X\")\n    true\n\n    iex> Pluscode.short?(\"8FVC9G8F+6X\")\n    false","ref":"Pluscode.html#short?/1-examples"},{"type":"function","title":"Pluscode.shorten/3","doc":"Remove characters from the start of an Open Location Code.\n\nThis uses a reference location to determine how many initial characters\ncan be removed from the OLC code. The number of characters that can be\nremoved depends on the distance between the code center and the reference\nlocation.","ref":"Pluscode.html#shorten/3"},{"type":"function","title":"Args - Pluscode.shorten/3","doc":"* `code` - A full Open Location Code to shorten.\n  * `latitude` - The reference latitude in signed decimal degrees.\n  * `longitude` - The reference longitude in signed decimal degrees.","ref":"Pluscode.html#shorten/3-args"},{"type":"function","title":"Returns - Pluscode.shorten/3","doc":"A string containing the shortened Open Location Code.","ref":"Pluscode.html#shorten/3-returns"},{"type":"function","title":"Rules - Pluscode.shorten/3","doc":"* The minimum number of characters that will be removed is four.\n  * If more than four characters can be removed, the additional characters\n    will be replaced with the padding character (0).\n  * At most eight characters will be removed.\n  * The reference location must be within 50% of the maximum range.","ref":"Pluscode.html#shorten/3-rules"},{"type":"function","title":"Examples - Pluscode.shorten/3","doc":"iex> Pluscode.shorten(\"8FVC9G8F+6X\", 47.5, 8.5)\n    \"9G8F+6X\"","ref":"Pluscode.html#shorten/3-examples"},{"type":"type","title":"Pluscode.t/0","doc":"","ref":"Pluscode.html#t:t/0"},{"type":"function","title":"Pluscode.valid?/1","doc":"Determines if a code is valid.\n\nTo be valid, all characters must be from the Open Location Code character\nset with at most one separator. The separator can be in any even-numbered\nposition up to the eighth digit.","ref":"Pluscode.html#valid?/1"},{"type":"function","title":"Args - Pluscode.valid?/1","doc":"* `code` - The code to validate.","ref":"Pluscode.html#valid?/1-args"},{"type":"function","title":"Returns - Pluscode.valid?/1","doc":"`true` if the code is valid, `false` otherwise.","ref":"Pluscode.html#valid?/1-returns"},{"type":"function","title":"Examples - Pluscode.valid?/1","doc":"iex> Pluscode.valid?(\"8FVC9G8F+6X\")\n    true\n\n    iex> Pluscode.valid?(\"8FVC9G8F+\")\n    true\n\n    iex> Pluscode.valid?(\"invalid\")\n    false","ref":"Pluscode.html#valid?/1-examples"},{"type":"extras","title":"Pluscode","doc":"# Pluscode\n\nAn Elixir implementation of Open Location Code (Plus Codes), a technology developed by Google that encodes location into a short, easy to share code. For more information, visit [plus.codes](https://plus.codes/).","ref":"readme.html"},{"type":"extras","title":"Features - Pluscode","doc":"- Encode latitude/longitude to Plus Codes\n- Decode Plus Codes to coordinates\n- Validate Plus Codes\n- Shorten codes relative to a reference location\n- Recover full codes from shortened versions\n- Full compatibility with the official specification","ref":"readme.html#features"},{"type":"extras","title":"Installation - Pluscode","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `pluscode` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:pluscode, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Pluscode","doc":"```elixir\n# Encode a location\niex> Pluscode.encode(47.365590, 8.524997)\n\"8FVC9G8F+6X\"\n\n# Encode with higher precision\niex> Pluscode.encode(47.365590, 8.524997, 11)\n\"8FVC9G8F+6XQ\"\n\n# Decode a code\niex> area = Pluscode.decode(\"8FVC9G8F+6X\")\niex> {area.latitude_center, area.longitude_center}\n{47.365625, 8.525}\n\n# Validate a code\niex> Pluscode.valid?(\"8FVC9G8F+6X\")\ntrue\n\n# Shorten a code (using a reference location)\niex> Pluscode.shorten(\"8FVC9G8F+6X\", 47.5, 8.5)\n\"9G8F+6X\"\n\n# Recover a full code from a short code\niex> Pluscode.recover_nearest(\"9G8F+6X\", 47.4, 8.6)\n\"8FVC9G8F+6X\"\n```","ref":"readme.html#usage"},{"type":"extras","title":"Documentation - Pluscode","doc":"Detailed documentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#documentation"},{"type":"extras","title":"License - Pluscode","doc":"This implementation is licensed under the Apache License, Version 2.0. See the LICENSE file for details.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}